==============
Cakemix :cake:
==============

|build| |codecov| |Gitpod ready to code|

English | Português_

Cakemix is a tool for creating code template generators like :code:`create-react-app` and :code:`npm init`. Avoiding you to waste time organizing a project.

.. links

.. _Português: ./locales/pt-br/README.rst

.. images

.. |build| image:: https://img.shields.io/github/workflow/status/vadolasi/cakemix/Python%20package
   :alt: Tests status

.. |codecov| image:: https://codecov.io/gh/vadolasi/cakemix/branch/master/graphs/badge.svg?branch=master
   :alt: Code corverage status

.. |Gitpod ready to code| image:: https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod
   :alt: Open in Gitpod.io
   :target: https://gitpod.io/#https://github.com/vadolasi/cakemix
